@@ -112,7 +112,13 @@ class UiForceDistance(QtWidgets.QWidget):
         return curves
 
     def add_files(self, files):
-        """ Populate self.data_set and display the first curve """
+        """Populate self.data_set and display the first curve
+
+        Parameters
+        ----------
+        files: list of pathlib.Path
+            List of experimental data files
+        """
         # The `mult` parameter is used to chunk the progress bar,
         # because we cannot use floats with `QProgressDialog`, but
         # we want to be able to show progress for files that contain
@@ -122,9 +128,8 @@ class UiForceDistance(QtWidgets.QWidget):
                                         "Stop", 1, len(files)*mult)
         bar.setWindowTitle("Loading data files")
         bar.setMinimumDuration(1000)
-        for ii, f in enumerate(files):
-            label = "Loading file\n{}".format(os.path.basename(f))
-            bar.setLabelText(label)
+        for ii, pp in enumerate(files):
+            bar.setLabelText(f"Loading file\n{pp}")
 
             def callback(partial):
                 """Call back method for a progress dialog
@@ -138,13 +143,14 @@ class UiForceDistance(QtWidgets.QWidget):
                     The progress for a single file
                 """
                 bar.setValue(int((ii+partial)*mult))
-                QtCore.QCoreApplication.instance().processEvents()
+                QtCore.QCoreApplication.instance().processEvents(
+                    QtCore.QEventLoop.AllEvents, 300)
                 if bar.wasCanceled():
                     # Raise a custom `AbortProgress` error, such that
                     # we can exit the parent for-loop.
                     raise AbortProgress
             try:
-                grp = nanite.IndentationGroup(f, callback=callback)
+                grp = nanite.IndentationGroup(pp, callback=callback)
                 callback(1)
             except afmformats.errors.FileFormatMetaDataError:
                 # ignore e.g. JPK callibration curves
@@ -154,7 +160,8 @@ class UiForceDistance(QtWidgets.QWidget):
                 # The custom error `AbortProgress` was called, because
                 # the user wants to stop loading the data.
                 break
-            self.data_set += grp
+            else:
+                self.data_set += grp
         bar.reset()
         bar.close()
         self.curve_list_setup()
@@ -292,6 +299,7 @@ class UiForceDistance(QtWidgets.QWidget):
             fdist = self.current_curve
         self.tab_info.update_info(fdist)
 
+    @QtCore.pyqtSlot()
     def on_cb_rating_scheme(self):
         """Switch rating scheme or import a new one"""
         scheme_id = self.cb_rating_scheme.currentIndex()
@@ -311,6 +319,7 @@ class UiForceDistance(QtWidgets.QWidget):
         else:
             self.on_params_init()
 
+    @QtCore.pyqtSlot()
     def on_curve_list(self):
         """Called when a new curve is selected"""
         fdist = self.current_curve
@@ -334,6 +343,7 @@ class UiForceDistance(QtWidgets.QWidget):
         # Autosave
         self.autosave(fdist)
 
+    @QtCore.pyqtSlot(QtCore.QModelIndex)
     def on_curve_list_item_changed(self, item):
         """An item in the curve list was changed
 
@@ -348,6 +358,7 @@ class UiForceDistance(QtWidgets.QWidget):
             self.tab_qmap.mpl_qmap_update()
             self.autosave(fdist)
 
+    @QtCore.pyqtSlot()
     def on_export_edelta(self):
         """Saves all edelta curves"""
         fname, _e = QtWidgets.QFileDialog.getSaveFileName(
@@ -381,7 +392,8 @@ class UiForceDistance(QtWidgets.QWidget):
                     pass
                 else:
                     res += [d, e]
-                QtCore.QCoreApplication.instance().processEvents()
+                QtCore.QCoreApplication.instance().processEvents(
+                    QtCore.QEventLoop.AllEvents, 300)
                 bar.setValue(ii+1)
 
             # export curves with numpy
@@ -394,6 +406,7 @@ class UiForceDistance(QtWidgets.QWidget):
             with io.open(fname, "ab") as fd:
                 np.savetxt(fd, np.array(res))
 
+    @QtCore.pyqtSlot()
     def on_export_fit_results(self):
         """Save metadata and fit results"""
         fdist_list = [fdist for fdist in self.selected_curves]
@@ -402,6 +415,7 @@ class UiForceDistance(QtWidgets.QWidget):
                                            identifier=self._instance_counter)
         dlg.show()
 
+    @QtCore.pyqtSlot()
     def on_fit_all(self):
         """Apply initial parameters to all curves and fit"""
         # We will fit all curves with the currently visible settings
@@ -409,17 +423,33 @@ class UiForceDistance(QtWidgets.QWidget):
                                         "Stop", 1, len(self.data_set))
         bar.setWindowTitle("Loading data files")
         bar.setMinimumDuration(1000)
+        errored = []
         for ii, fdist in enumerate(self.data_set):
-            QtCore.QCoreApplication.instance().processEvents()
+            QtCore.QCoreApplication.instance().processEvents(
+                QtCore.QEventLoop.AllEvents, 300)
             if bar.wasCanceled():
                 break
-            self.tab_preprocess.fit_apply_preprocessing(fdist)
-            self.tab_fit.fit_approach_retract(fdist, update_ui=False)
+            try:
+                self.tab_preprocess.fit_apply_preprocessing(fdist)
+                self.tab_fit.fit_approach_retract(fdist, update_ui=False)
+                self.curve_list_update(item=ii)
+            except BaseException as e:
+                errored.append([fdist.path, e.__class__.__name__, e.args])
             bar.setValue(ii+1)
-            self.curve_list_update(item=ii)
-        # Display map
+        # display qmap
         self.tab_qmap.mpl_qmap_update()
+        if errored:
+            # Show warning dialog with datasets that issued an error
+            msg = "The following curves could not be processed properly:<br>"
+            for pp, err, eargs in errored:
+                msg += f"<br>{pp.name}: {err} ({', '.join(list(eargs))})<br>"
+            QtWidgets.QMessageBox.warning(
+                self,
+                "Some curves could not be processed!",
+                msg,
+            )
 
+    @QtCore.pyqtSlot()
     def on_model(self):
         """Called when the fitting model is changed"""
         # The difference to "on_params_init" is that we
@@ -433,10 +463,12 @@ class UiForceDistance(QtWidgets.QWidget):
         self.curve_list_update()
         self.tab_qmap.mpl_qmap_update()
 
+    @QtCore.pyqtSlot()
     def on_mpl_curve_update(self):
         fdist = self.current_curve
         self.widget_fdist.mpl_curve_update(fdist)
 
+    @QtCore.pyqtSlot()
     def on_params_init(self):
         """Called when the initial parameters are changed"""
         fdist = self.current_curve
@@ -448,6 +480,7 @@ class UiForceDistance(QtWidgets.QWidget):
         self.curve_list_update(item=idx)
         self.tab_qmap.mpl_qmap_update()
 
+    @QtCore.pyqtSlot()
     def on_rating_threshold(self):
         """(De)select curves according to threshold rating"""
         thresh = self.sp_rating_thresh.value()
@@ -467,6 +500,7 @@ class UiForceDistance(QtWidgets.QWidget):
         for fdist in self.data_set:
             self.autosave(fdist)
 
+    @QtCore.pyqtSlot(int)
     def on_tab_changed(self, index):
         """Called when the tab on the right hand is changed"""
         if hasattr(self, "user_tab_selected"):
@@ -489,6 +523,7 @@ class UiForceDistance(QtWidgets.QWidget):
 
         self.user_tab_selected = curtab
 
+    @QtCore.pyqtSlot()
     def on_user_rate(self):
         """Start the curve rater"""
         cont = QtWidgets.QFileDialog.getSaveFileName(
